From b04a454813bccfd110c2cc04d1a01e4bf1a09060 Mon Sep 17 00:00:00 2001
From: Christian Heller <c.heller@plomlompom.de>
Date: Fri, 14 Nov 2014 13:59:46 +0100
Subject: [PATCH] Client: Rename read_outfile() to more precise read_queue().

---
 src/client/io.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/client/io.c b/src/client/io.c
index 35e42e7..233a60c 100644
--- a/src/client/io.c
+++ b/src/client/io.c
@@ -80,8 +80,8 @@ static uint8_t read_worldstate();
  */
 static void test_and_poll_server();
 
-/* Read server out file for messages, act on them (i.e. derive log messages). */
-static uint8_t read_outfile();
+/* Read queue, act on them (as of right now only: derive log messages). */
+static uint8_t read_queue();
 
 
 
@@ -230,7 +230,7 @@ static void test_and_poll_server()
 
 
 
-static uint8_t read_outfile()
+static uint8_t read_queue()
 {
     uint8_t ret = 0;
     char * msg;
@@ -288,7 +288,7 @@ extern char * io_loop()
             world.winch = 0;
             change_in_client++;
         }
-        if (change_in_client || read_worldstate() || read_outfile())
+        if (change_in_client || read_worldstate() || read_queue())
         {
             if (world.turn != last_focused_turn && world.focus_each_turn)
             {
-- 
2.30.2